/*! \file debug.h

  \brief debug utility.

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef   debug_h
#define   debug_h

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#if        (0 == MYDEBUG)
#define debug_open(a,b)                         do{}while(0) /*!< for debug */
#define debug_close()                           do{}while(0) /*!< for debug */
#define debug_log(...)                          do{}while(0) /*!< for debug */
#define debug_image_out(data,size)              do{}while(0) /*!< for debug */
#define debug_check_memory_allocate_counter()   do{}while(0) /*!< for debug */
#define debug_show_env()                        do{}while(0) /*!< for debug */
#define debug_show_cups_cmd_option_list(a,b)    do{}while(0) /*!< for debug */
#define debug_show_cups_page_size(a)            do{}while(0) /*!< for debug */
#define debug_show_escp_page_size(a,b)          do{}while(0) /*!< for debug */
#define debug_show_raster_info(a,b,c,d)         do{}while(0) /*!< for debug */
#define debug_show_scanline_info(a,b,c)         do{}while(0) /*!< for debug */
#define ARGERROR(a)                                      (a) /*!< for debug */
#define dbgprintf(...)                          do{}while(0) /*!< for debug */
#define FUNCSTART                               do{}while(0) /*!< for debug */
#define DEBUGINFO                               do{}while(0) /*!< for debug */
#define DEBUG_ERROR_TRACE                       do{}while(0) /*!< for debug */
#else  /* (0 != MYDEBUG) */

#include <cups/cups.h>
#include "common.h"
#include "option.h"
#include "escpcmd.h"

FUNCTION void dbgprintf(const char *fmt, ... );
FUNCTION void debug_open( char *printer_name, const char *job_id );
FUNCTION void debug_close( void );
FUNCTION void debug_log(const char *file, const int line, const char *func, const char *fmt, ... );
FUNCTION void debug_image_out( unsigned char *data, size_t size );
FUNCTION void debug_check_memory_allocate_counter( void );
FUNCTION void debug_show_env( void );
FUNCTION void debug_show_cups_cmd_option_list( int num_cmd_options, cups_option_t *cmd_options );
FUNCTION void debug_show_cups_page_size( const ppd_size_t *page_size );
FUNCTION void debug_show_escp_page_size( escp_page_info_t *escp_page_info, unsigned long design_base_reso);
FUNCTION void debug_show_raster_info( int page, unsigned width, unsigned height, unsigned row_count );
FUNCTION void debug_show_scanline_info( int scan_line, unsigned short band_line, unsigned short skip_line_num );

#define DEBUGINFO debug_log(dbg,"\n") /*!< for debug */

#define FUNCSTART dbgprintf("\n\
----------------------------------------------------------------\n\
%s:%d:%s: start\n", dbg);       /*!< \brief function start index */

#define ARGERROR(a) (a) ? debug_log(dbg,"ERROR: %s\n", #a), exit(1), 1 : 0 /*!< \see #ASSERT() */

#define DEBUG_ERROR_TRACE debug_log(dbg,"error.\n") /*!< \brief debug error tracer
                                                      for debug */
#endif  /* (0 != MYDEBUG) */

#endif /* debug_h */
/* end of file */
